@@ -38,7 +38,7 @@ class DataGenerator(Iterator):
     """ Infinite Data Generator which automatically creates batches from a list of samples.
 
     The created batches are model ready. This generator can be supplied directly
-    to a [Neural_Network][aucmedi.neural_network.model.Neural_Network] train() & predict()
+    to a [NeuralNetwork][aucmedi.neural_network.model.NeuralNetwork] train() & predict()
     function (also compatible to tensorflow.keras.model fit() & predict() function).
 
     The DataGenerator is the second of the three pillars of AUCMEDI.
@@ -46,7 +46,7 @@ class DataGenerator(Iterator):
     ??? info "Pillars of AUCMEDI"
         - [aucmedi.data_processing.io_data.input_interface][]
         - [aucmedi.data_processing.data_generator.DataGenerator][]
-        - [aucmedi.neural_network.model.Neural_Network][]
+        - [aucmedi.neural_network.model.NeuralNetwork][]
 
     The DataGenerator can be used for training, validation as well as for prediction.
 
@@ -56,7 +56,7 @@ class DataGenerator(Iterator):
         from aucmedi import *
 
         # Initialize model
-        model = Neural_Network(n_labels=8, channels=3, architecture="2D.ResNet50")
+        model = NeuralNetwork(n_labels=8, channels=3, architecture="2D.ResNet50")
 
         # Do some training
         datagen_train = DataGenerator(samples[:100], "images_dir/", labels=class_ohe[:100],
@@ -91,7 +91,7 @@ class DataGenerator(Iterator):
 
         my_metadata = np.random.rand(len(samples), 10)
 
-        my_model = Neural_Network(n_labels=8, channels=3, architecture="2D.DenseNet121",
+        my_model = NeuralNetwork(n_labels=8, channels=3, architecture="2D.DenseNet121",
                                   meta_variables=10)
 
         my_dg = DataGenerator(samples, "images_dir/",
@@ -160,7 +160,7 @@ class DataGenerator(Iterator):
                                                 Recommended for large images or volumes to reduce CPU computing time.
             loader (io_loader function):        Function for loading samples/images from disk.
             seed (int):                         Seed to ensure reproducibility for random function.
-            **kwargs (dictionary):              Additional parameters for the sample loader.
+            **kwargs (dict):              Additional parameters for the sample loader.
         """
         # Cache class variables
         self.labels = labels
@@ -213,8 +213,10 @@ class DataGenerator(Iterator):
         # If prepare_image modus activated
         # -> Preprocess images beforehand and store them to disk for fast usage later
         if self.prepare_images:
-            tmp_dir = tempfile.mkdtemp(prefix="aucmedi.tmp.", suffix=".data")
-            self.prepare_dir = tmp_dir
+            self.prepare_dir_object = tempfile.TemporaryDirectory(
+                                               prefix="aucmedi.tmp.",
+                                               suffix=".data")
+            self.prepare_dir = self.prepare_dir_object.name
 
             # Preprocess image for each index - Sequential
             if self.workers == 0 or self.workers == 1:
@@ -229,7 +231,8 @@ class DataGenerator(Iterator):
                     mp_params = zip(index_array, repeat(False), repeat(False),
                                     repeat(False), repeat(True))
                     pool.starmap(self.preprocess_image, mp_params)
-            print("A directory for image preparation was created:", tmp_dir)
+            print("A directory for image preparation was created:",
+                  self.prepare_dir)
 
         # Pass initialization parameters to parent Iterator class
         size = len(samples)
